@@ -157,3 +157,11 @@ def make_folders_complete_set(main_folderpath):
     make_a_folder(main_folderpath+'/Features')
 
 
+
+#this looks for the violence type, note requires that a variable has _sb at the end
+def find_the_violence_type(string):
+    if string.endswith('_sb'): output = 'state-based violence'
+    elif string.endswith('_ns'): output = 'non-state violence'
+    elif string.endswith('_os'): output = 'one-sided violence'
+    else: output = 'please check the variable name'
+    return output
